@@ -39,7 +39,8 @@ take HOME if set (with assertments), otherwise xeffectiveuserhome
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
